mcp.client

High-level MCP Client API.

High-level MCP Client API.
raw docstring

mcp.http

StreamableHTTP transport for MCP (Protocol Version 2026-07-24). Uses single-endpoint POST requests and manages Mcp-Session-Id.

StreamableHTTP transport for MCP (Protocol Version 2026-07-24).
Uses single-endpoint POST requests and manages Mcp-Session-Id.
raw docstring

mcp.protocol

Pure Clojure definitions for JSON-RPC 2.0 and MCP protocol messages.

Pure Clojure definitions for JSON-RPC 2.0 and MCP protocol messages.
raw docstring

mcp.server

Pure Clojure MCP Server implementation using stdin/stdout.

Pure Clojure MCP Server implementation using stdin/stdout.
raw docstring

mcp.stdio

Stdio transport for MCP using java.lang.ProcessBuilder. Manages a background thread reading stdout and matching responses to requests.

Stdio transport for MCP using java.lang.ProcessBuilder.
Manages a background thread reading stdout and matching responses to requests.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries