Clojure only.

mcp.server

Pure Clojure MCP Server implementation using stdin/stdout.

Pure Clojure MCP Server implementation using stdin/stdout.
raw docstring

run-serverclj

(run-server server)

Starts the MCP server, listening on stdin and writing to stdout. Expects a server definition map containing :name, :version, and :tools.

Starts the MCP server, listening on stdin and writing to stdout.
Expects a server definition map containing :name, :version, and :tools.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries