mcp.stdio

Stdio transport for MCP using java.lang.ProcessBuilder. Manages a background thread reading stdout and matching responses to requests.

Stdio transport for MCP using java.lang.ProcessBuilder.
Manages a background thread reading stdout and matching responses to requests.
raw docstring

create-stdio-transportclj

(create-stdio-transport command-args & {:keys [notifications-callback]})

Creates a StdioTransport. Expects a vector of command args. e.g., ["npx" "-y" "@modelcontextprotocol/server-filesystem" "/tmp"]

Creates a StdioTransport. Expects a vector of command args.
e.g., ["npx" "-y" "@modelcontextprotocol/server-filesystem" "/tmp"]
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries