Abstract transport layer for MCP communication.
Abstract transport layer for MCP communication.
(close! this)Closes the transport connection and cleans up resources.
Closes the transport connection and cleans up resources.
(send! this message)Sends a JSON-RPC message map. Returns a promise that will deliver the parsed JSON response map (or nil for notifications).
Sends a JSON-RPC message map. Returns a promise that will deliver the parsed JSON response map (or nil for notifications).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |