High-level MCP Client API.
High-level MCP Client API.
(call-tool client tool-name arguments)Calls a specific tool by name with the provided arguments map.
Calls a specific tool by name with the provided arguments map.
(connect transport-type target opts)Initializes the MCP client. transport-type: :stdio or :http target: vector of args for stdio, or URL string for http. opts: map of options (e.g., {:client-name "my-app" :client-version "1.0.0"})
Initializes the MCP client.
transport-type: :stdio or :http
target: vector of args for stdio, or URL string for http.
opts: map of options (e.g., {:client-name "my-app" :client-version "1.0.0"})(disconnect client)Closes the connection to the MCP server.
Closes the connection to the MCP server.
(list-tools client)Fetches the list of available tools from the MCP server.
Fetches the list of available tools from the MCP server.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |