Pure Clojure MCP Server implementation using stdin/stdout.
Pure Clojure MCP Server implementation using stdin/stdout.
(run-server server)Starts the MCP server, listening on stdin and writing to stdout. Expects a server definition map containing :name, :version, and :tools.
Starts the MCP server, listening on stdin and writing to stdout. Expects a server definition map containing :name, :version, and :tools.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |